import React from "react";
import { Route, Routes } from "react-router-dom";
import { BrainAtlasType, MultiLang } from "../config";
import CoverPage from "../custom/CoverPage";
import RelatedLink from "../custom/RelatedLink";
import Database from "../database/Database";
import DatabaseTop from "../database/DatabaseTop";
import XoopsPathRedirect from "./XoopsPathRedirect";

interface Props {
  lang: MultiLang;
  type: BrainAtlasType;
  isHtml: boolean;
  isLink: boolean;
}

const MainContent: React.FC<Props> = (props: Props) => {
  const { lang, type, isHtml, isLink } = props;
  return (
    <div className="mainContent">
      {isHtml ? (
        isLink ? (
          <RelatedLink lang={lang} type={type} />
        ) : (
          <CoverPage lang={lang} type={type} />
        )
      ) : (
        <Routes>
          <Route index element={<DatabaseTop lang={lang} type={type} />} />
          <Route path="modules/xoonips/*" element={<Database lang={lang} type={type} />} />
          <Route path="*" element={<XoopsPathRedirect lang={lang} />} />
        </Routes>
      )}
    </div>
  );
};

export default MainContent;
