import React from "react";
import { useNavigate } from "react-router-dom";
import Config, { BrainAtlasType, MultiLang } from "../config";
import Functions from "../functions";
import ItemType from "./item-type";
import AdvancedSearchQuery from "./lib/AdvancedSearchQuery";
import ItemUtil from "./lib/ItemUtil";

interface PropsFC {
  lang: MultiLang;
  type: BrainAtlasType;
}

interface Props extends PropsFC {
  navigate: any;
}

class DatabaseAdvancedSearch extends React.Component<Props> {
  private query: AdvancedSearchQuery = new AdvancedSearchQuery();

  constructor(props: Props) {
    super(props);
    this.handleClickSearchButton = this.handleClickSearchButton.bind(this);
  }

  handleClickSearchButton() {
    const { type, navigate } = this.props;
    if (!this.query.empty()) {
      const url = ItemUtil.getSearchByAdvancedKeywordsUrl(type, this.query);
      navigate(url);
    }
  }

  render() {
    const { lang } = this.props;

    return (
      <div className="advancedSearch">
        <h3>{Functions.mlang("[en]Search Items[/en][ja]アイテム検索[/ja]", lang)}</h3>
        <div className="search">
          <button className="formButton" onClick={this.handleClickSearchButton}>
            Search
          </button>
        </div>
        {Config.XOONIPS_ITEMTYPES.map((type) => {
          return <ItemType.AdvancedSearch key={type} type={"xnp" + type} lang={lang} query={this.query} />;
        })}
        <div className="search">
          <button className="formButton" onClick={this.handleClickSearchButton}>
            Search
          </button>
        </div>
      </div>
    );
  }
}

const DatabaseAdvancedSearchFC: React.FC<PropsFC> = (props: PropsFC) => {
  const { lang, type } = props;
  return <DatabaseAdvancedSearch lang={lang} type={type} navigate={useNavigate()} />;
};

export default DatabaseAdvancedSearchFC;
