import React from "react";
import { Helmet } from "react-helmet-async";
import Loading from "../common/lib/Loading";
import PageNotFound from "../common/lib/PageNotFound";
import { BrainAtlasType, MultiLang } from "../config";
import Functions from "../functions";
import ItemType from "./item-type";
import ItemUtil, { Item } from "./lib/ItemUtil";

interface Props {
  lang: MultiLang;
  type: BrainAtlasType;
  id: number;
  doi: string;
}

interface State {
  loading: boolean;
  item: Item | null;
}

class DatabaseDetailItem extends React.Component<Props, State> {
  constructor(props: Props) {
    super(props);
    this.state = {
      loading: true,
      item: null,
    };
  }

  componentDidMount() {
    this.updateItem();
  }

  componentDidUpdate(prevProps: Props, prevState: State) {
    const { id, doi } = this.props;
    if (id !== prevProps.id || doi !== prevProps.doi) {
      this.updateItem();
    }
  }

  updateItem() {
    const { id, doi, type } = this.props;
    if (doi !== "") {
      ItemUtil.getByDoi(type, doi, (item) => {
        this.setState({ loading: false, item });
      });
    } else if (id !== 0) {
      ItemUtil.get(type, id, (item) => {
        this.setState({ loading: false, item });
      });
    }
  }

  render() {
    const { lang, type } = this.props;
    if (this.state.loading) {
      return <Loading />;
    }
    if (this.state.item === null) {
      return <PageNotFound lang={lang} />;
    }
    return (
      <>
        <Helmet>
          <title>
            {Functions.mlang(this.state.item.title, lang)} - {Functions.mlang("[en]Database[/en][ja]データベース[/ja]", lang)} - {Functions.siteTitle(lang)}
          </title>
        </Helmet>
        <h3>{Functions.mlang("[en]Detail[/en][ja]詳細[/ja]", lang)}</h3>
        <br />
        <ItemType.Detail lang={lang} item={this.state.item} type={type} />
      </>
    );
  }
}

export default DatabaseDetailItem;
