import React from "react";
import { useLocation } from "react-router-dom";
import { BrainAtlasType, MultiLang } from "../config";
import AdvancedSearchQuery from "./lib/AdvancedSearchQuery";
import DatabaseListItem from "./lib/DatabaseListItem";
import ItemUtil, { SearchCallbackFunc, SortCondition } from "./lib/ItemUtil";

interface PropsFC {
  lang: MultiLang;
  type: BrainAtlasType;
}

interface Props extends PropsFC {
  location: any;
}

interface State {
  search: string;
  query: AdvancedSearchQuery;
}

class DatabaseSearchByAdvancedKeyword extends React.Component<Props, State> {
  constructor(props: Props) {
    super(props);
    const search = props.location.search;
    const query = ItemUtil.getAdvancedSearchQueryByQuery(search);
    this.state = { search, query };
    this.searchFunc = this.searchFunc.bind(this);
  }

  static getDerivedStateFromProps(nextProps: Props, prevState: State) {
    const search = nextProps.location.search;
    if (prevState.search !== search) {
      const query = ItemUtil.getAdvancedSearchQueryByQuery(search);
      return { search, query };
    }
    return null;
  }

  getUrl() {
    const { type } = this.props;
    return ItemUtil.getSearchByAdvancedKeywordsUrl(type, this.state.query);
  }

  searchFunc(condition: SortCondition, func: SearchCallbackFunc) {
    const { type } = this.props;
    ItemUtil.getListByAdvancedSearchQuery(type, this.state.query, condition, func);
  }

  render() {
    const { lang, type } = this.props;
    const baseUrl = this.getUrl();
    return (
      <div className="list">
        <h3>Listing item</h3>
        <DatabaseListItem lang={lang} url={baseUrl} search={this.searchFunc} type={type} />
      </div>
    );
  }
}

const DatabaseSearchByAdvancedKeywordFC: React.FC<PropsFC> = (props: PropsFC) => {
  const { lang, type } = props;
  return <DatabaseSearchByAdvancedKeyword lang={lang} type={type} location={useLocation()} />;
};

export default DatabaseSearchByAdvancedKeywordFC;
