import React, { Fragment } from "react";
import { Helmet } from "react-helmet-async";
import { Link } from "react-router-dom";
import PageNotFound from "../common/lib/PageNotFound";
import { BrainAtlasType, MultiLang } from "../config";
import Functions from "../functions";
import DatabaseListIndex from "./lib/DatabaseListIndex";
import DatabaseListItem from "./lib/DatabaseListItem";
import IndexUtil, { Index } from "./lib/IndexUtil";
import ItemUtil, { SearchCallbackFunc, SortCondition } from "./lib/ItemUtil";

export interface Props {
  lang: MultiLang;
  type: BrainAtlasType;
  indexId: number;
}

class DatabaseSearchByIndexId extends React.Component<Props> {
  constructor(props: Props) {
    super(props);
    this.searchFunc = this.searchFunc.bind(this);
  }

  getUrl() {
    const { type, indexId } = this.props;
    if (indexId === 0) {
      return "/";
    }
    return IndexUtil.getUrl(type, indexId);
  }

  searchFunc(condition: SortCondition, func: SearchCallbackFunc) {
    const { type, indexId } = this.props;
    if (indexId === 0) {
      const res = { total: 0, data: [] };
      func(res);
    } else {
      ItemUtil.getListByIndexId(type, indexId, condition, func);
    }
  }

  render() {
    const { lang, type, indexId } = this.props;
    const index = IndexUtil.get(type, indexId);
    if (index === null) {
      return <PageNotFound lang={lang} />;
    }
    const baseUrl = this.getUrl();
    const pIndexes = IndexUtil.getParents(type, indexId);
    const parents = pIndexes.map((value: Index) => {
      const url: string = IndexUtil.getUrl(type, value.id);
      const title = Functions.mlang(value.title, lang);
      return (
        <Fragment key={value.id}>
          / <Link to={url}>{title}</Link>{" "}
        </Fragment>
      );
    });
    const title = pIndexes
      .map((value) => {
        return "/" + Functions.mlang(value.title, lang);
      })
      .join("");
    return (
      <div className="list">
        <Helmet>
          <title>
            {Functions.mlang(title, lang)} - {Functions.mlang("[en]Database[/en][ja]データベース[/ja]", lang)} - {Functions.siteTitle(lang)}
          </title>
        </Helmet>
        <h3>{Functions.mlang("[en]Listing item[/en][ja]アイテム一覧[/ja]", lang)}</h3>
        <div>{parents}</div>
        <DatabaseListIndex lang={lang} index={index} type={type} />
        <DatabaseListItem lang={lang} url={baseUrl} search={this.searchFunc} type={type} />
      </div>
    );
  }
}

export default DatabaseSearchByIndexId;
