import React from "react";
import { useLocation } from "react-router-dom";
import { BrainAtlasType, MultiLang } from "../config";
import Functions from "../functions";
import DatabaseListItem from "./lib/DatabaseListItem";
import ItemUtil, { KeywordSearchType, SearchCallbackFunc, SortCondition } from "./lib/ItemUtil";

interface PropsFC {
  lang: MultiLang;
  type: BrainAtlasType;
}

interface Props extends PropsFC {
  location: any;
}

interface State {
  type: KeywordSearchType;
  keyword: string;
}

class DatabaseSearchByKeyword extends React.Component<Props, State> {
  constructor(props: Props) {
    super(props);
    const { location } = props;
    const { type, keyword } = ItemUtil.getSearchKeywordByQuery(location.search);
    this.state = { type, keyword };
    this.searchFunc = this.searchFunc.bind(this);
  }

  static getDerivedStateFromProps(nextProps: Props, prevState: State) {
    const { type, keyword } = ItemUtil.getSearchKeywordByQuery(nextProps.location.search);
    if (prevState.type !== type || prevState.keyword !== keyword) {
      return { type, keyword };
    }
    return null;
  }

  getUrl() {
    const { type } = this.props;
    return ItemUtil.getSearchByKeywordUrl(type, this.state.type, this.state.keyword);
  }

  searchFunc(condition: SortCondition, func: SearchCallbackFunc) {
    const { type } = this.props;
    if (this.state.keyword === "") {
      const res = { total: 0, data: [] };
      func(res);
    } else {
      ItemUtil.getListByKeyword(type, this.state.type, this.state.keyword, condition, func);
    }
  }

  render() {
    const { lang, type } = this.props;
    const baseUrl = this.getUrl();
    return (
      <div className="list">
        <h3>{Functions.mlang("[en]Listing item[/en][ja]アイテム一覧[/ja]", lang)}</h3>
        <p>
          {Functions.mlang("[en]Search Keyword[/en][ja]検索キーワード[/ja]", lang)} : {this.state.keyword}
        </p>
        <DatabaseListItem lang={lang} url={baseUrl} search={this.searchFunc} type={type} />
      </div>
    );
  }
}

const DatabaseSearchByKeywordFC: React.FC<PropsFC> = (props: PropsFC) => {
  const { lang, type } = props;
  return <DatabaseSearchByKeyword lang={lang} type={type} location={useLocation()} />;
};

export default DatabaseSearchByKeywordFC;
